'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var storageBlob = require('@azure/storage-blob');
var chalk = _interopDefault(require('chalk'));

function getIncomingFiles({
  req,
  data
}) {
  var _req$files;

  const fileData = data;
  const file = (_req$files = req.files) === null || _req$files === void 0 ? void 0 : _req$files.file;
  let files = [];

  if (file) {
    files = [{
      filename: fileData.filename,
      mimeType: fileData.mimeType,
      buffer: file.data
    }];

    if (fileData !== null && fileData !== void 0 && fileData.sizes) {
      Object.entries(fileData.sizes).forEach(([key, resizedFileData]) => {
        files = files.concat({
          filename: `${resizedFileData.filename}`,
          mimeType: data.mimeType,
          buffer: req.payloadUploadSizes[key]
        });
      });
    }
  }

  return {
    hasFile: Boolean(file),
    files
  };
}

async function ensureBlobContainerExists(options) {
  const blobServiceClient = storageBlob.BlobServiceClient.fromConnectionString(options.connectionString);
  const containerClient = blobServiceClient.getContainerClient(options.containerName);
  const createContainerResponse = await containerClient.createIfNotExists({
    access: "blob"
  });

  if (createContainerResponse.succeeded) {
    console.log(`${chalk.green("Successfully created storage container")} ${options.containerName}`);
  } else {
    console.log(`${chalk.cyan("Skipped storage container creation")} ${options.containerName}`, createContainerResponse.errorCode);
  }
}

function createUploadMediaHooks(options) {
  if (options.allowContainerCreate) {
    ensureBlobContainerExists(options);
  }

  const afterRead = [({
    doc
  }) => {
    doc.url = `${options.baseUrl}/${options.containerName}/${doc.filename}`;
    Object.keys(doc.sizes).forEach(k => {
      doc.sizes[k].url = `${options.baseUrl}/${options.containerName}/${doc.sizes[k].filename}`;
    });
  }];
  const beforeChange = [async ({
    data,
    req,
    originalDoc
  }) => {
    const {
      hasFile,
      files
    } = getIncomingFiles({
      data,
      req
    });

    if (hasFile) {
      const blobServiceClient = storageBlob.BlobServiceClient.fromConnectionString(options.connectionString);
      const containerClient = blobServiceClient.getContainerClient(options.containerName);

      for (const file of files) {
        const blobName = file.filename;
        const blockBlobClient = containerClient.getBlockBlobClient(blobName);
        await blockBlobClient.upload(file.buffer, file.buffer.byteLength, {
          blobHTTPHeaders: {
            blobContentType: file.mimeType
          }
        });
        console.log(`${chalk.green("Successfully uploaded")} ${blobName}`);
      }
    } else {
      console.log(`${chalk.cyan("Skipped upload")} ${originalDoc === null || originalDoc === void 0 ? void 0 : originalDoc.id}`);
    }
  }];
  const afterDelete = [async ({
    req: _req,
    id: _id,
    doc
  }) => {
    const fileData = doc;
    const blobServiceClient = storageBlob.BlobServiceClient.fromConnectionString(options.connectionString);
    const containerClient = blobServiceClient.getContainerClient(options.containerName);
    const filesToDelete = [fileData.filename, ...Object.entries(fileData.sizes).map(([_key, resizedFileData]) => resizedFileData.filename)];

    for (const fileName of filesToDelete) {
      const blobName = fileName;
      const blockBlobClient = containerClient.getBlockBlobClient(blobName);
      const deleteBlobResponse = await blockBlobClient.deleteIfExists();

      if (deleteBlobResponse.succeeded) {
        console.log(`${chalk.green("Successfully deleted")} ${blobName}`);
      } else {
        console.log(`${chalk.red("Delete failed")} ${blobName}`);
      }
    }
  }];
  return {
    beforeChange,
    afterDelete,
    afterRead
  };
}

exports.createUploadMediaHooks = createUploadMediaHooks;
//# sourceMappingURL=index.js.map
